parserFwk.pyparsing.Suppress

Package parserFwk :: Module pyparsing :: Class Suppress |
[frames | no frames]

## Type Suppress

         object --+
                  |
      ParserElement --+
                      |
    ParseElementEnhance --+
                          |
             TokenConverter --+
                              |
                             Suppress

Converter for ignoring the results of a parsed expression.

Method Summary
| `postParse(self, instring, loc, tokenlist)`
| ``suppress`(self)` Suppresses the output of this ParserElement; useful to keep punctuation from cluttering up returned output.
Inherited from `TokenConverter`: `__init__` Inherited from `ParseElementEnhance`: `__str__`, `checkRecursion`, `ignore`, `leaveWhitespace`, `parseImpl`, `streamline`, `validate` Inherited from `ParserElement`: `__add__`, `__and__`, `__invert__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__ror__`, `__rxor__`, `__xor__`, `addParseAction`, `copy`, `enablePackrat`, `normalizeParseActionArgs`, `parseFile`, `parseString`, `parseWithTabs`, `preParse`, `resetCache`, `scanString`, `searchString`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setName`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `skipIgnorables`, `transformString`, `tryParse` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
`list` | `__slotnames__` = `[]`
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Instance Method Details

### suppress(self) Suppresses the output of this ParserElement; useful to keep punctuation from cluttering up returned output. Overrides: `parserFwk.pyparsing.ParserElement.suppress` (inherited documentation)

Class Variable Details

    ### __slotnames__ Type: `list` Value:
        []

Generated by Epydoc 2.1 on Wed Apr 11 17:02:38 2007 | http://epydoc.sf.net